Features:
        
        - Scrapes the HTML from https://eztv.yt/ (previously eztv.it, but they've migrated)
        - Offers a simple API to get a list of shows and episodes for TV seasons
        - Has unit tests, and tests that that run against the live website
        - Actively tested and working as of August 2015
        
        See https://github.com/jaysh/eztvit-python for details.